/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.ui;

import org.eclipse.swt.widgets.Composite;

/**
 * A descriptor that is used to create pages that display the contents 
 * of an {@link ITargetContainer}.
 * 
 * TODO: How are descriptors associated with particular container types
 * 
 * <p>
 * <b>Note:</b> This class/interface is part of an interim API that is still under 
 * development and expected to change significantly before reaching stability. 
 * It is being made available at this early stage to solicit feedback from pioneering 
 * adopters on the understanding that any code that uses this API will almost 
 * certainly be broken (repeatedly) as the API evolves.
 * </p>
 */
public interface ISitePageDescriptor {
	
	/**
	 * Return the unique identifier of this page descriptor.
	 * It is a good practice to prefix the identifier with the
	 * contributing plugin's id.
	 * @return the unique identifier of this page descriptor
	 */
	String getId();
	
	/**
	 * Create a page that can be used to display the contents
	 * of the {@link ITargetContainer} to which this descritor
	 * is associated.
	 * @param parent the parent composite that will contain the page
	 * @return the page
	 */
	ISitePage createPage(Composite parent);

}
